@@ -34,9 +34,12 @@
 from __future__ import absolute_import
 
 import pytest
+from _pytest.config import Config  # noqa F401
+from _pytest.config.argparsing import Parser  # noqa F401
 
 
 def pytest_addoption(parser):
+	# type: (Parser) -> None
 	parser.addoption(
 		"--ucs-test-tags-prohibited",
 		action="append",
@@ -78,6 +81,7 @@ def pytest_addoption(parser):
 
 
 def pytest_configure(config):
+	# type: (Config) -> None
 	config.addinivalue_line("markers", "slow: test case is slow")
 	config.addinivalue_line("markers", "tags(name): tag a test case")
 	config.addinivalue_line("markers", "roles(names): specify roles")
@@ -85,15 +89,21 @@ def pytest_configure(config):
 
 
 def pytest_runtest_setup(item):
+	# type: (pytest.Item) -> None
 	check_tags(item)
 	check_roles(item)
 	check_exposure(item)
 
 
 def check_tags(item):
+	# type: (pytest.Item) -> None
 	tags_required = set(item.config.getoption("--ucs-test-tags-required") or [])
 	tags_prohibited = set(item.config.getoption("--ucs-test-tags-prohibited") or [])
-	tags = set(tag for mark in item.iter_markers(name="tags") for tag in mark.args) or set(item.config.getoption("--ucs-test-default-tags", []))
+	tags = {
+		tag
+		for mark in item.iter_markers(name="tags")
+		for tag in mark.args
+	} or set(item.config.getoption("--ucs-test-default-tags", []))
 
 	prohibited = tags & tags_prohibited
 	if prohibited:
@@ -105,23 +115,33 @@ def check_tags(item):
 
 
 def check_roles(item):
+	# type: (pytest.Item) -> None
 	from univention.config_registry import ucr
 	from univention.testing.data import CheckRoles
-	roles_required = set(role for mark in item.iter_markers(name="roles") for role in mark.args)
-	roles_prohibited = set(role for mark in item.iter_markers(name="roles_not") for role in mark.args)
+	roles_required = {
+		role
+		for mark in item.iter_markers(name="roles")
+		for role in mark.args
+	}
+	roles_prohibited = {
+		role
+		for mark in item.iter_markers(name="roles_not")
+		for role in mark.args
+	}
 	overlap = roles_required & roles_prohibited
 	if overlap:
 		roles = roles_required - roles_prohibited
 	elif roles_required:
-		roles = set(roles_required)
+		roles = roles_required
 	else:
-		roles = set(CheckRoles.ROLES) - set(roles_prohibited)
+		roles = set(CheckRoles.ROLES) - roles_prohibited
 
 	if ucr['server/role'] not in roles:
 		pytest.skip('Wrong role: %s not in (%s)' % (ucr['server/role'], ','.join(roles)))
 
 
 def check_exposure(item):
+	# type: (pytest.Item) -> None
 	from univention.testing.data import CheckExposure
 	required_exposure = item.config.getoption("--ucs-test-exposure")
 	if not required_exposure:
